@@ -8,13 +8,16 @@ from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
 from django.db.backends import utils
 
+from django_extensions.settings import DEFAULT_PRINT_SQL_TRUNCATE_CHARS
+
 
 @contextmanager
 def monkey_patch_cursordebugwrapper(print_sql=None, print_sql_location=False, truncate=None, logger=print, confprefix="DJANGO_EXTENSIONS"):
     if not print_sql:
         yield
     else:
-        truncate = getattr(settings, '%s_PRINT_SQL_TRUNCATE' % confprefix, 1000)
+        if truncate is None:
+            truncate = getattr(settings, '%s_PRINT_SQL_TRUNCATE' % confprefix, DEFAULT_PRINT_SQL_TRUNCATE_CHARS)
 
         # Code orginally from http://gist.github.com/118990
         sqlparse = None
